<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_956cd32298a229f9768f1096f077" . "ace3" => base64_decode("Ym9keS1wbG" . "Fpbg=="), "_44e986c04f41a08b56a383c7b3a8" . "8ee2" => base64_decode("c2VuZ" . "GVy"), "_a1e707d0" . "2a236dade" . "bd15a45e6" . "5ebdb6" => base64_decode("YXR0YWNobWVu" . "dC1jb3VudA=="), "_6e1c717cf3cbf1af982ed74d4336b7" . "f1" => base64_decode("Ym9keS1od" . "G1s"), "_f589476" . "007fa133" . "f457c3ef" . "29ddfa56" . "6" => base64_decode("V" . "G" . "8" . "="), "_f39f5346e313e4dd1a" . "c3a7bd8032beda" => base64_decode("c3Vic3Ry" . "X2NvbXBh" . "cmU="), "_618a4aeb9fecc4" . "592a4521f34876f" . "a29" => base64_decode("ZnJ" . "vbQ" . "=="), "_8c575917cbaedf1e7efae84939402b" . "ff" => base64_decode("U3V" . "iam" . "Vjd" . "A=="), "_97ea09a7faf27c52c6eff69" . "773df1d8a" => base64_decode("dGltZXN0Y" . "W1w"), "_d706c160e45b" . "f7434fff82a59" . "76f0e19" => base64_decode("YXJyYXlfa2V" . "5cw=="), "_9c050c786fc87170cbb84fc6a8b13c" . "b6" => base64_decode("YXR0YWNobWVudC" . "0="), "_1d6c68a0262e8fa0bed1" . "215b7224a98e" => base64_decode("cmVjaXBpZW" . "50"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_d706c160e45bf7434f" . "ff82a5976f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_a1e707d02a236dadeb" . "d15a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_f39f5346e313e4" . "dd1ac3a7bd8032b" . "eda"]($key, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_9c050c786fc87170" . "cbb84fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_1d6c68a0262e8fa0bed1215b72" . "24a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_618a4aeb9fecc459" . "2a4521f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_f589476007fa133f457c3" . "ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_8c575917cbaedf1e7efae84939402" . "bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_6e1c717c" . "f3cbf1af9" . "82ed74d43" . "36b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_956cd32298a229f9768f109" . "6f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_97ea09a7faf27c52c6eff69773d" . "f1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_44e986c04f41a08b5" . "6a383c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}