<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("project" . "_id" => base64_decode("cHJvam" . "VjdF9p" . "ZA=="), "_ced92d7b3" . "91285c8a26" . "846f1f4bd3" . "128" => base64_decode("Ym9keV90Z" . "Xh0"), "_bfda889b74ea561" . "b14325e30e7d7542" . "6" => base64_decode("Ym9" . "keV" . "9od" . "G1s"), "_618a4aeb9fecc4592a4521f" . "34876fa29" => base64_decode("ZnJvbQ" . "=="), "_c35473364fa7a050299058f332ec29c" . "1" => base64_decode("ZXh" . "jZX" . "B0a" . "W9u"), "_67a0d624aebcceb0abd5ce56a53f" . "f06f" => base64_decode("ZGF" . "0ZQ" . "=="), "_f656816961e8573806141c558b1" . "84fe2" => base64_decode("c3ViamVj" . "dA=="), "_a3d82c5df38e194c9" . "c73e3ccb4223bbc" => base64_decode("ZW1haWxfZGF0YQ" . "=="), "_03b1f0ce" . "e835582d1" . "158dce267" . "8b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUg" . "bWFpbCByZWNlaXZlZCBzdWJzY3Jp" . "YmVy"), "_460e1aeb3113a1676ce59a8f" . "40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm" . "9yIGluZm9jYXB0dXJlIHByb2plY3Q="), "_5d40a2cf1c525fb252" . "bf5599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaW" . "RlbnRpZmllZCBmb3IgbWFpbDsgc3ViamVjdCAn"), "_e608e5b5c4c34a" . "67ba97ef84c1e16" . "199" => base64_decode("Jw=" . "="), "_9b16fa2683095e" . "67d7c8b265a8081" . "d0b" => base64_decode("TWFpbFJlY2VpdmVkR" . "XZlbnRSZWNlaXZlcg" . "=="), "_376d30c40857357a4d4cbb1ffaa" . "25817" => base64_decode("d" . "G" . "8" . "="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_9b16fa2683095e67" . "d7c8b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_03b1f0cee8" . "35582d1158d" . "ce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_5d40a2cf1c525fb2" . "52bf5599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_e608e5b5c4c34a67ba97ef84c1e" . "16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_618a4aeb9fecc4592a4521f3487" . "6fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_376d30c40857357a4d4cbb1f" . "faa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_f656816961e8573806141c558b" . "184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_ced92d7b391285c8a26846f1f4" . "bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_bfda889b74ea56" . "1b14325e30e7d75" . "426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_67a0d624aeb" . "cceb0abd5ce5" . "6a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_460e1aeb311" . "3a1676ce59a8" . "f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["projec" . "t_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_a3d82c5df38e194c9c73e3ccb42" . "23bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_c35473364fa7a0" . "50299058f332ec2" . "9c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}